esdoc-cdf2cim
=============

Python client for mapping netCDF files to CIM documents.


What is ES-DOC ?
--------------------------------------

ES-DOC stands for Earth Science - Documentation.  It's goal is to
provide software tools and services in order to support the
distribution of earth science documentation.


What is esdoc-cdf2cim ?
--------------------------------------

esdoc-cdf2cim is a python client library for automating the
publication of simulation documents in CIM v2.0 format.


Why esdoc-cdf2cim ?
--------------------------------------

A documentation eco-system is only as good as the available client
tools.  ES-DOC provides the cdf2cim client tool so as to simplify
leveraging the ES-DOC eco-ssytem in the python programming language.


Who uses esdoc-cdf2cim ?
--------------------------------------

ESG-F data node managers.



How to install esdoc-cdf2cim ?
--------------------------------------

pip install cdf2cim


How to integrate esdoc-cdf2cim into the ESG Publisher?
------------------------------------------------------

https://github.com/ES-DOC/esdoc-cdf2cim/blob/master/ESG_Publisher_Integration.pdf

Further Information? 
--------------------

See http:es-doc.org
